pub struct Entries<T: Config<I>, I: 'static = ()>(/* private fields */);Expand description
Represents a collection of entries within an index.
Backed by a WeakBoundedVec to enforce an upper bound on the number of
entries (via Config::MaxIndexEntries) while maintaining efficient,
bounded storage.
This serves as the low-level container for all EntryInfo items that
constitute an index.
Implementations
Sourceimpl<T: Config<I>, I: 'static> Entries<T, I>
impl<T: Config<I>, I: 'static> Entries<T, I>
Sourcepub fn entries(&self) -> Vec<EntryInfo<T, I>>
pub fn entries(&self) -> Vec<EntryInfo<T, I>>
Returns all EntryInfo items contained in this list as a owned vector.
Sourcepub fn add_entry(&mut self, entry: EntryInfo<T, I>) -> Result<(), DispatchError>
pub fn add_entry(&mut self, entry: EntryInfo<T, I>) -> Result<(), DispatchError>
Adds a new EntryInfo to the list of entries.
Returns DispatchError if vector bound exhausted
or duplicate found.
Sourcepub fn remove_entry(
&mut self,
entry: &EntryDigest<T>,
) -> Result<(), DispatchError>
pub fn remove_entry( &mut self, entry: &EntryDigest<T>, ) -> Result<(), DispatchError>
Removes an existing EntryInfo from the entries-list.
Returns DispatchError if entry of digest not found.