VirtualReceipt

Type Alias VirtualReceipt 

pub type VirtualReceipt<T, I = ()> = LazyVirtual<T, ReceiptAsset, ReceiptRational, ReceiptTime, ReceiptAddon, I>;
Virtual representation of a receipt (claim).

Represents a deferred claim over balance value in the lazy model:

  • created on deposit
  • resolved on withdrawal

Its value is computed dynamically based on global balance state.

Aliased Type

pub struct VirtualReceipt<T, I = ()> { /* private fields */ }