pub struct IndexInfo<T: Config<I>, I: 'static = ()> { /* private fields */ }Expand description
Represents an index containing multiple entries.
An IndexInfo tracks the overall capital, total balance, and the entries themselves.
Implementations
Sourceimpl<T: Config<I>, I: 'static> IndexInfo<T, I>
impl<T: Config<I>, I: 'static> IndexInfo<T, I>
Sourcepub fn principal(&self) -> AssetOf<T, I>
pub fn principal(&self) -> AssetOf<T, I>
Returns the index’s principal, i.e. the total amount deposited by proprietors.
Sourcepub fn reveal_entries(&self) -> Entries<T, I>
pub fn reveal_entries(&self) -> Entries<T, I>
Reveal the actual entries Entries
Sourcepub fn entry_exists(&self, entry: &EntryDigest<T>) -> DispatchResult
pub fn entry_exists(&self, entry: &EntryDigest<T>) -> DispatchResult
Checks if an entry of digest exists in the index.