pub struct PoolInfo<T: Config<I>, I: 'static = ()> { /* private fields */ }Expand description
Represents a managed pool derived from an index.
PoolInfo aggregates capital, commission, and the collection of slots,
each of which represents a portion of the pool linked to underlying entries.
Unlike indexes, pools are mutable and can have their slot balances adjusted dynamically.
Pools are created from an IndexInfo (or Entries), allowing the
shares of each entry to be translated into slots within the pool.
Pool’s slot shares/variants can then be adjusted over time, while the pool’s commission and structure remain consistent.
Implementations
Sourceimpl<T: Config<I>, I: 'static> PoolInfo<T, I>
impl<T: Config<I>, I: 'static> PoolInfo<T, I>
Sourcepub fn balance(&self) -> LazyBalanceOf<T, I>
pub fn balance(&self) -> LazyBalanceOf<T, I>
Returns the pool’s lazy balance.
Sourcepub fn capital(&self) -> T::Shares
pub fn capital(&self) -> T::Shares
Returns the pool’s total capital i.e., total shares of all slots.
Sourcepub fn commission(&self) -> T::Commission
pub fn commission(&self) -> T::Commission
Returns the pool’s commission i.e., manager’s share while resolving the pool’s commit.
Sourcepub fn slot_exists(&self, slot: &SlotDigest<T>) -> DispatchResult
pub fn slot_exists(&self, slot: &SlotDigest<T>) -> DispatchResult
Checks if a slot of digest exists in the pool.