pub type CommitInstance<T, I = ()> = VirtualReceipt<T, I>;Expand description
Represents a single commit instance created by a commit operation.
This is a thin wrapper over VirtualReceipt, capturing a receipt of the
deposit at the time of commitment-similar to a bill that is later required
during withdrawal resolution.
A commitment may accumulate multiple commit instances over time. Each instance is immutable, with aggregation and evaluation performed at higher levels.
Aliased Type
pub struct CommitInstance<T, I = ()> { /* private fields */ }