pub type VirtualBalance<T, I = ()> = LazyVirtual<T, BalanceAsset, BalanceRational, BalanceTime, BalanceAddon, I>;Expand description
Virtual representation of a live lazy-balance.
Backed by the lazy balance model, meaning storage layouts are interpreted dynamically by the caller rather than the implementor.
Aliased Type
pub struct VirtualBalance<T, I = ()> { /* private fields */ }